@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2003 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Common C++.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// The exception is that, if you link the Common C++ library with other files
-// to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
-//
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
 //
-// If you write modifications of your own for Common C++, it is your choice
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file socket.h
@@ -501,7 +498,7 @@ public:
 	 */
 	IPV4Host getIPV4Peer(tpport_t *port = NULL) const;
 
-	inline IPV4Host getPeer(tpport_t *port) const
+	inline IPV4Host getPeer(tpport_t *port = NULL) const
 		{return getIPV4Peer(port);}
 
 #ifdef	CCXX_IPV6
@@ -517,7 +514,7 @@ public:
 	 */
 	IPV4Host getIPV4Local(tpport_t *port = NULL) const;
 
-	inline IPV4Host getLocal(tpport_t *port) const
+	inline IPV4Host getLocal(tpport_t *port = NULL) const
 		{return getIPV4Local(port);}
 
 #ifdef	CCXX_IPV6
@@ -1235,8 +1232,7 @@ public:
 	 * @param ia internet host address of the client.
 	 * @param port number of the client.
 	 */
-	virtual bool onAccept(const IPV4Host &ia, tpport_t port)
-		{return true;}
+	virtual bool onAccept(const IPV4Host &ia, tpport_t port);
 
 	/**
 	 * Fetch out the socket.
@@ -1308,8 +1304,7 @@ public:
 	/**
 	 * Use base socket handler for ending this socket.
 	 */
-	virtual ~TCPSocket()
-		{endSocket();};
+	virtual ~TCPSocket();
 };
 
 #ifdef  CCXX_IPV6
@@ -1355,8 +1350,7 @@ public:
 	 * @param ia internet host address of the client.
 	 * @param port number of the client.
 	 */
-	virtual bool onAccept(const IPV6Host &ia, tpport_t port)
-		{return true;}
+	virtual bool onAccept(const IPV6Host &ia, tpport_t port);
 
 	/**
 	 * Fetch out the socket.
@@ -1424,8 +1418,7 @@ public:
 	/**
 	 * Use base socket handler for ending this socket.
 	 */
-	virtual ~TCPV6Socket()
-		{endSocket();};
+	virtual ~TCPV6Socket();
 };
 
 #endif
@@ -1633,15 +1626,7 @@ public:
 	 * Flush and empty all buffers, and then remove the allocated
 	 * buffers.
 	 */
-	virtual ~TCPStream()
-		{
-#ifdef	CCXX_EXCEPTIONS
-		try { endStream(); }
-		catch( ... ) { if ( ! std::uncaught_exception()) throw; }
-#else
-		endStream();
-#endif
-		};
+	virtual ~TCPStream();
 
 	/**
 	 * Flushes the stream input and output buffers, writes
@@ -1868,7 +1853,7 @@ public:
 	 * Flush and empty all buffers, and then remove the allocated
 	 * buffers.
 	 */
-	virtual ~SimpleTCPStream() { endStream(); };
+	virtual ~SimpleTCPStream();
 
 	/**
 	 * @brief Get the status of pending stream data. 
