@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2003 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //  
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-// 
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file thread.h
@@ -1138,8 +1135,7 @@ protected:
 	 * @see #exit
 	 * @see #run
 	 */
-	virtual void final(void)
-		{return;};
+	virtual void final(void);
 
 	/**
 	 * The initial method is called by a newly created thread when it
@@ -1152,8 +1148,7 @@ protected:
 	 * @see #run
 	 * @see #final
 	 */
-	virtual void initial(void)
-		{return;};
+	virtual void initial(void);
 
 	/**
 	 * Since getParent() and getThread() only refer to an object of the
@@ -1164,8 +1159,7 @@ protected:
 	 *
 	 * @return pointer to derived class specific data.
 	 */
-	virtual void* getExtended(void)
-		{return NULL;};
+	virtual void* getExtended(void);
 
 	/**
 	 * When a thread terminates, it now sends a notification message
@@ -1174,8 +1168,7 @@ protected:
 	 * 
 	 * @param - the thread that has terminated.
 	 */
-	virtual void notify(Thread*)
-		{return;};
+	virtual void notify(Thread*);
 
 	/**
 	 * Used to properly exit from a Thread derived run() or initial()
@@ -1508,36 +1501,31 @@ protected:
 	 * A derivable method to call when a SIGALRM is being delivered
 	 * to a specific thread.
 	 */
-	virtual void onTimer(void)
-		{return;};
+	virtual void onTimer(void);
 
 	/**
 	 * A derived method to handle hangup events being delivered
 	 * to a specific thread.
 	 */
-	virtual void onHangup(void)
-		{return;};
+	virtual void onHangup(void);
 
 	/**
 	 * A derived method to call when a SIGABRT is being delivered
 	 * to a specific thread.
 	 */
-	virtual void onException(void)
-		{return;};
+	virtual void onException(void);
 
 	/**
 	 * A derived method to call when a SIGPIPE is being delivered
 	 * to a specific thread.
 	 */
-	virtual void onDisconnect(void)
-		{return;};
+	virtual void onDisconnect(void);
 
 	/**
 	 * A derived method to handle asynchronous I/O requests delivered
 	 * to the specified thread.
 	 */
-	virtual void onPolling(void)
-		{return;};
+	virtual void onPolling(void);
 
 	/**
 	 * A derivable method to call for delivering a signal event to
@@ -1545,8 +1533,7 @@ protected:
 	 *
 	 * @param - posix signal id.
 	 */
-	virtual void onSignal(int)
-		{return;};
+	virtual void onSignal(int);
 	
 	/**
 	 * Used to specify a timeout event that can be delivered to the
@@ -1662,10 +1649,12 @@ public:
 	 * Create a unique thread specific container.
 	 */
 	ThreadKey();
+
 	/**
 	 * Destroy a thread specific container and any contents reserved.
 	 */
 	virtual ~ThreadKey();
+
 	/**
 	 * Get the value of the pointer for the thread specific data
 	 * container.  A unique pointer can be set for each execution
@@ -1674,6 +1663,7 @@ public:
 	 * @return a unique void * for each execution context.
 	 */
 	void *getKey(void);
+
 	/**
 	 * Set the value of the pointer for the current thread specific
 	 * execution context.  This can be used to store thread context
