@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2002 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-// 
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 #include <cc++/config.h>
 #ifdef	CCXX_WITHOUT_EXTRAS
@@ -169,6 +166,11 @@ Serial::Serial(const char *fname)
 #endif
 }
 
+Serial::~Serial()
+{
+	endSerial();
+}
+
 void Serial::initConfig(void)
 {
 #ifdef	WIN32
@@ -1238,18 +1240,11 @@ int TTYStream::underflow(void)
 		return (unsigned char)*gptr();
 
 	rlen = (ssize_t)((gbuf + bufsize) - eback());
-	if(timeout)
-	{
-		if(!Serial::isPending(pendingInput, timeout))
-		{
-			clear(ios::failbit | rdstate());
-			error(errTimeout);
-			return EOF;
-		}
-			rlen = -1;
-	}
+	if(timeout && !Serial::isPending(pendingInput, timeout))
+		rlen = -1;
 	else
 		rlen = aRead((char *)eback(), rlen);
+
 	if(rlen < 1)
 	{
 		if(rlen < 0)
@@ -1527,6 +1522,22 @@ SerialPort::~SerialPort()
 	endSerial();
 }
 
+void SerialPort::expired(void)
+{
+}
+
+void SerialPort::pending(void)
+{
+}
+
+void SerialPort::disconnect(void)
+{
+}
+
+void SerialPort::output(void)
+{
+}
+
 void SerialPort::setTimer(timeout_t ptimer)
 {
 	TimerPort::setTimer(ptimer);
@@ -1600,6 +1611,18 @@ SerialService::~SerialService()
 		delete first;
 }
 
+void SerialService::onUpdate(unsigned char flag)
+{
+}
+
+void SerialService::onEvent(void)
+{
+}
+
+void SerialService::onCallback(SerialPort *port)
+{
+}
+
 void SerialService::attach(SerialPort *port)
 {
 	enterMutex();
